( cd usr/lib ; rm -rf libwebkit-1.0.so.1 )
( cd usr/lib ; ln -sf libwebkit-1.0.so.1.0.0 libwebkit-1.0.so.1 )
( cd usr/lib ; rm -rf libwebkit-1.0.so )
( cd usr/lib ; ln -sf libwebkit-1.0.so.1.0.0 libwebkit-1.0.so )
